==> qmmp-0.9.8.tar.bz2: qmmp-0.9.8/src/plugins/Input/gme/translations/gme_plugin_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_CN">
<context>
    <name>DecoderGmeFactory</name>
    <message>
        <location filename="../decodergmefactory.cpp" line="49"/>
        <source>GME Plugin</source>
        <translation>GME 插件</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="52"/>
        <source>Game Music Files</source>
        <translation>Game 音乐文件</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="116"/>
        <source>About GME Audio Plugin</source>
        <translation>关于 GME 音频插件</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="117"/>
        <source>Qmmp GME Audio Plugin</source>
        <translation>Qmmp GME 音频插件</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="118"/>
        <source>This plugin uses Game_Music_Emu library to play game music files</source>
        <translation>此插件使用 Game_Music_Emu 库来播放 game 音乐文件</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="119"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>GME Plugin Settings</source>
        <translation>GME插件设置</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="34"/>
        <source>Fadeout length:</source>
        <translation>淡出长度</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="44"/>
        <source>ms</source>
        <translation>毫秒</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="57"/>
        <source>Enable fadeout</source>
        <translation>开启淡出功能</translation>
    </message>
</context>
</TS>

==> qmmp-0.12.18.tar.bz2: qmmp-0.12.18/src/plugins/Input/gme/translations/gme_plugin_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_CN">
<context>
    <name>DecoderGmeFactory</name>
    <message>
        <location filename="../decodergmefactory.cpp" line="38"/>
        <source>GME Plugin</source>
        <translation>GME 插件</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="41"/>
        <source>Game Music Files</source>
        <translation>Game 音乐文件</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="103"/>
        <source>About GME Audio Plugin</source>
        <translation>关于 GME 音频插件</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="104"/>
        <source>Qmmp GME Audio Plugin</source>
        <translation>Qmmp GME 音频插件</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="105"/>
        <source>This plugin uses Game_Music_Emu library to play game music files</source>
        <translation>此插件使用 Game_Music_Emu 库来播放 game 音乐文件</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="106"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>GME Plugin Settings</source>
        <translation>GME插件设置</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="34"/>
        <source>Fadeout length:</source>
        <translation>淡出长度</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="44"/>
        <source>ms</source>
        <translation>毫秒</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="57"/>
        <source>Enable fadeout</source>
        <translation>开启淡出功能</translation>
    </message>
</context>
</TS>
